Welcome to |project| documentation!
===================================

.. sidebar-links::
   :home:
   :pypi:

.. toctree::
   :maxdepth: 1

   history


.. automodule:: jaraco.windows.clipboard
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.cred
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.dpapi
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.environ
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.error
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.eventlog
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.inet
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.memory
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.mmap
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.msie
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.net
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.power
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.privilege
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.registry
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.reparse
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.security
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.services
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.shell
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.timers
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.timezone
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.ui
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.user
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.util
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.vpn
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.xmouse
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.filesystem
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.filesystem.backports
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.windows.filesystem.change
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

